import 'pusher_event.dart';

/// Client applications should implement this interface if they want to be
/// notified when events are received on a public or private channel.
///
/// <p>
/// To bind your implementation of this interface to a channel, either:
/// </p>
/// <ul>
/// <li>Call {@link com.pusher.client.Pusher#subscribe(String)} to subscribe and
/// receive an instance of {@link Channel}.</li>
/// <li>Call {@link Channel#bind(String, SubscriptionEventListener)} to bind your
/// listener to a specified event.</li>
/// </ul>
///
/// <p>
/// Or, call
/// {@link com.pusher.client.Pusher#subscribe(String, ChannelEventListener, String...)}
/// to subscribe to a channel and bind your listener to one or more events at the
/// same time.
/// </p>
///
abstract class SubscriptionEventListener {
  /// Callback that is fired whenever an event that this
  /// {@linkplain SubscriptionEventListener} has been bound to is received.
  ///
  /// @param event
  ///            A PusherEvent object which exposes the whole event.
  ///            See {@linkplain PusherEvent} for more.
  void onEvent(final PusherEvent event);
}
